# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mlconjug3',
 'mlconjug3.PyVerbiste',
 'mlconjug3.conjug_manager',
 'mlconjug3.constants',
 'mlconjug3.dataset',
 'mlconjug3.feature_extractor',
 'mlconjug3.models',
 'mlconjug3.utils',
 'mlconjug3.verbs',
 'tests']

package_data = \
{'': ['*'],
 'mlconjug3': ['data/conjug_manager/*',
               'data/models/*',
               'locale/es/LC_MESSAGES/*',
               'locale/fr/LC_MESSAGES/*',
               'locale/it/LC_MESSAGES/*',
               'locale/pt/LC_MESSAGES/*',
               'locale/ro/LC_MESSAGES/*'],
 'tests': ['models/*']}

install_requires = \
['click>=8.1.3,<8.2.0',
 'colorama>=0.4.6,<0.5.0',
 'cython>=0.29.33,<0.30.0',
 'defusedxml>=0.7.1,<0.8.0',
 'hydra-core>=1.3.1,<1.4.0',
 'joblib>=1.2.0,<1.3.0',
 'numpy>=1.24.1,<1.25.0',
 'pyyaml>=6.0,<6.1',
 'rich>=13.2.0,<13.3.0',
 'scikit-learn==1.2.0',
 'tomlkit>=0.11.6,<0.12.0']

entry_points = \
{'console_scripts': ['mlconjug3 = mlconjug3.cli:main']}

setup_kwargs = {
    'name': 'mlconjug3',
    'version': '3.10.0',
    'description': 'A Command Line application and Python library to conjugate French, English, Spanish, Italian, Portuguese and Romanian verbs using Machine Learning techniques.',
    'long_description': '.. image:: https://raw.githubusercontent.com/SekouDiaoNlp/mlconjug3/master/logo/logotype2%20mlconjug.png\n        :target: https://pypi.python.org/pypi/mlconjug3\n        :alt: mlconjug3 PyPi Home Page\n\n----\n\n.. image:: https://img.shields.io/badge/Maintained%3F-yes-green.svg\n        :target: https://GitHub.com/SekouDiaoNlp/mlconjug3/graphs/commit-activity\n        :alt: Package Maintenance Status\n\n.. image:: https://img.shields.io/badge/maintainer-SekouDiaoNlp-blue\n        :target: https://GitHub.com/SekouDiaoNlp/mlconjug3\n        :alt: Package Maintener\n\n.. image:: https://bestpractices.coreinfrastructure.org/projects/6961/badge\n        :target: https://bestpractices.coreinfrastructure.org/projects/6961/\n        :alt: OpenSSF Best Practices\n\n.. image:: https://api.securityscorecards.dev/projects/github.com/SekouDiaoNlp/mlconjug3/badge\n        :target: https://api.securityscorecards.dev/projects/github.com/SekouDiaoNlp/mlconjug3/\n        :alt: OpenSSF ScoreCard\n\n.. image:: https://github.com/SekouDiaoNlp/mlconjug3/workflows/mlconjug3/badge.svg\n        :target: https://github.com/SekouDiaoNlp/mlconjug3/actions\n        :alt: Build status on Windows, MacOs and Linux\n\n.. image:: https://img.shields.io/pypi/v/mlconjug3.svg\n        :target: https://pypi.python.org/pypi/mlconjug3\n        :alt: Pypi Python Package Index Status\n\n.. image:: https://anaconda.org/conda-forge/mlconjug3/badges/version.svg\n        :target: https://anaconda.org/conda-forge/mlconjug3\n        :alt: Anaconda Package Index Status\n\n.. image:: https://img.shields.io/pypi/pyversions/mlconjug3\n        :target: https://pypi.python.org/pypi/mlconjug3\n        :alt: Compatible Python versions\n\n.. image:: https://img.shields.io/conda/pn/conda-forge/mlconjug3?color=dark%20green&label=Supported%20platforms\n        :target: https://anaconda.org/conda-forge/mlconjug3\n        :alt: Supported platforms\n\n.. image:: https://readthedocs.org/projects/mlconjug3/badge/?version=latest\n        :target: https://mlconjug3.readthedocs.io/en/latest/readme.html\n        :alt: Documentation Status\n\n.. image:: https://pyup.io/repos/github/SekouDiaoNlp/mlconjug3/shield.svg\n        :target: https://pyup.io/repos/github/SekouDiaoNlp/mlconjug3/\n        :alt: Dependencies status\n\n.. image:: https://codecov.io/gh/SekouDiaoNlp/mlconjug3/branch/master/graph/badge.svg\n        :target: https://codecov.io/gh/SekouDiaoNlp/mlconjug3\n        :alt: Code Coverage Status\n\n.. image:: https://snyk-widget.herokuapp.com/badge/pip/mlconjug3/badge.svg\n        :target: https://snyk.io/test/github/SekouDiaoNlp/mlconjug3?targetFile=requirements.txt\n        :alt: Code Vulnerability Status\n\n.. image:: https://img.shields.io/conda/dn/conda-forge/mlconjug?label=Anaconda%20Total%20Downloads\n        :target: https://anaconda.org/conda-forge/mlconjug3\n        :alt: Conda\n\n.. image:: https://img.shields.io/mastodon/follow/109313632815812004?domain=https%3A%2F%2Ffosstodon.org&style=plastic\n        :target: https://fosstodon.org/@SekouDiao\n        :alt: Follow me on Mastodon\n\n\n----\n\n=========\nmlconjug3\n=========\n\nA Command Line application and Python library to conjugate verbs in French, English, Spanish, Italian, Portuguese and Romanian (more soon) using Machine Learning techniques.\n\n- Conjugate any verb in one of the supported languages, even completely new or made-up verbs, with the help of a pre-trained Machine Learning model.\n- The pre-trained models are composed of a binary feature extractor, a feature selector using Linear Support Vector Classification, and a classifier using Stochastic Gradient Descent.\n- Easily modify and retrain the models using any compatible classifiers from scikit-learn.\n- Uses Verbiste as the training data for the French model, and unsupervised learning techniques to generate the data for the English, Spanish, Italian, Portuguese and Romanian models.\n\n\n----\n\n.. image:: https://raw.githubusercontent.com/SekouDiaoNlp/mlconjug3/master/docs/images/to_be.png\n        :alt: Conjugation for the verb to be.\n        \n----\n\n* Free software: MIT license\n* Documentation: https://mlconjug3.readthedocs.io/en/latest/readme.html\n\n\nSupported Languages\n-------------------\n\n- French\n- English\n- Spanish\n- Italian\n- Portuguese\n- Romanian\n\n\nFeatures\n--------\n\n- Command Line Interface tool.\n- Easy to use and intuitive API.\n- Includes pre-trained models with 99% + accuracy in predicting conjugation class of unknown verbs.\n- Easily train new models or add new languages.\n- Uses caching and multiprocessing for maximum performance.\n- Easily integrate mlconjug3 in your own projects.\n- Extensive documentation.\n- Powerful machine learning algorithms for accurate verb conjugation predictions.\n- Support for multiple languages including English, Spanish, French, and German.\n- Customizable settings to fine-tune performance and adapt to different use cases.\n- Robust error handling and troubleshooting capabilities.\n- Regular updates and improvements to ensure optimal performance.\n- Community support and contributions to continuously expand the library\'s capabilities.\n- Integration with popular libraries such as scikit-learn and numpy for machine learning tasks.\n\n\n\nInstallation\n------------\n\nTo install mlconjug3, you have multiple options:\n\n- Using pip: \n  This is the preferred method to install mlconjug3, as it will always install the most recent stable release. \n  To install mlconjug3, run this command in your terminal:\n\n.. code-block:: console\n\n  $ pip install mlconjug3\n\n\nIf you don\'t have `pip`_ installed, this `Python installation guide`_ can guide you through the process.\n\n- Using pipx_ (recommended for users who want to avoid conflicts with other Python packages):\n\n.. code-block:: console\n\n  $ pipx install mlconjug3\n\n\n- Using conda:\n  You can also install mlconjug3 by using Anaconda_ or Miniconda_ instead of `pip`.\n  To install Anaconda or Miniconda, please follow the installation instructions on their respective websites.\n  After having installed Anaconda or Miniconda, run these commands in your terminal:\n\n.. code-block:: console\n\n  $ conda config --add channels conda-forge\n  $ conda config --set channel_priority strict\n  $ conda install mlconjug3\n  \nIf you already have Anaconda or Miniconda available on your system, just type this in your terminal:\n\n.. code-block:: console\n\n  $ conda install -c conda-forge mlconjug3\n\n.. warning::\n  If you intend to install mlconjug3 on a Apple Macbook with an Apple M1 or M2 processor or newer,\n  it is advised that you install mlconjug3 by using the conda installation method as all dependencies will be pre-compiled.\n\n.. _pip: https://pip.pypa.io\n.. _pipx: https://github.com/pypa/pipx\n.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/\n.. _Anaconda: https://www.anaconda.com/products/individual\n.. _Miniconda: https://docs.conda.io/en/latest/miniconda.html\n\n\n\nFrom sources\n~~~~~~~~~~~~\n\nThe sources for mlconjug3 can be downloaded from the `Github repo`_.\n\nYou can either clone the public repository:\n\n.. code-block:: console\n\n    $ git clone git://github.com/SekouDiaoNlp/mlconjug3\n\nOr download the `tarball`_:\n\n.. code-block:: console\n\n    $ curl  -OL https://github.com/SekouDiaoNlp/mlconjug3/tarball/master\n\nOnce you have a copy of the source, get in the source directory and you can install it with:\n\n.. code-block:: console\n\n    $ python setup.py install\n\nAlternatively, you can use poetry to install the software:\n\n.. code-block:: console\n\n    $ pip install poetry\n    \n    $ poetry install\n\n\n.. _Github repo: https://github.com/SekouDiaoNlp/mlconjug3\n.. _tarball: https://github.com/SekouDiaoNlp/mlconjug3/tarball/master\n\n\n\nAcademic publications citing mlconjug3\n--------------------------------------\n\n- | Gerard Canal, Senka Krivic ́, Paul Luff, Andrew Coles.\n  | "`PlanVerb: Domain-Independent Verbalization and Summary of Task Plans`_".\n  | Thirty-Sixth AAAI Conference on Artificial Intelligence (AAAI-22), 2022.\n\n- | Mike Hongfei Wu.\n  | "`Extensions and Applications of Deep Probabilistic Inference for Generative Models`_".\n  | A DISSERTATION SUBMITTED TO THE DEPARTMENT OF COMPUTER SCIENCE AND THE COMMITTEE ON GRADUATE STUDIES OF STANFORD UNIVERSITY IN PARTIAL FULFILLMENT OF THE REQUIREMENTS FOR THE DEGREE OF DOCTOR OF PHILOSOPHY. May 2022.\n\n- | Spencer Ng, Lucy Teaford, Andy Yang, and Isaiah Zwick-Schachter.\n  | "`Fluorescing Questions: Effects of Semantic Perturbations on BERT Performance in SQuAD 1.1`_".\n  | CMSC 25610: Computational Linguistics University of Chicago, 2021.\n\n- | Ali Malik and Mike Wu and Vrinda Vasavada and Jinpeng Song and John Mitchell and Noah D. Goodman and Chris Piech.\n  | "`Generative Grading Neural Approximate Parsing for Automated Student Feedback`_".\n  | Proceedings of the 34th AAAI conference on Artificial Intelligence, 2019.\n\n\nBibTeX\n------\n\nIf you want to cite mlconjug3 in an academic publication use this citation format:\n\n.. code:: bibtex\n\n   @article{mlconjug3,\n     title={mlconjug3},\n     author={Sekou Diao},\n     journal={GitHub. Note: https://github.com/SekouDiaoNlp/mlconjug3 Cited by},\n     year={2023}\n   }\n\n\nSoftware projects using mlconjug3\n---------------------------------\n\n\n- | `Machine Translation Service`_\n  | Translation flask API for the Helsinki NLP models available in the Huggingface Transformers library.\n- | `NLP-Suite`_\n  | NLP Suite is a package of tools designed for non-specialists, for scholars with no knowledge or little knowledge of Natural Language Processing.\n- | `Gender Bias Visualization`_\n  | This project offers tools to visualize the gender bias in pre-trained language models to better understand the prejudices in the data.\n- | `Text Adaptation To Context`_\n  | This project uses language models to generate text that is well suited to the type of publication.\n- | `verbecc-svc`_\n  | Dockerized microservice with REST API for conjugation of any verb in French and Spanish.\n- | `nvhtml`_\n  | A tool to Manage and tansform HTML documents.\n- | `Tux`_\n  | A Tux bot.\n- | `twitter-bot`_\n  | Tweets the words of the French language. Largely inspired by the @botducul (identical lexicon, but code in Python) and the @botsupervnr.\n  | Posts on @botduslip. Stores the position of the last tweeted word in a Redis database.\n- | `verb-form-helper`_\n  | This project offers a tool to help learn differnt verbal forms.\n- | `NLP Tasks`_\n  | A collection of common NLP tasks such as dataset parsing and explicit semantic extraction.\n- | `Facemask Detection`_\n  | This project offers a model which recognizes covid-19 masks.\n- | `Bad Excuses for Zoom Abuses`_\n  | Need an excuse for why you can\'t show up in your Zoom lectures? Just generate one here!\n- | `NLP`_\n  | Repository to store Natural Language Processing models.\n- | `Virtual Assistant`_\n  | This is a simple virtual assistant. With it, you can search the Internet, access websites, open programs, and more using just your voice.\n  | This virtual assistant supports the English and Portuguese languages and has many settings that you can adjust to your liking.\n- | `Bad Advice`_\n  | This python module responds to yes or no questions. It dishes out its advice at random.\n  | Disclaimer: Do not actually act on this advice ;)\n- | `Spanish Conjugations Quiz`_\n  | Python+Flask web app that uses mlconjug to dynamically generate foreign language conjugation questions.\n- | `Silver Rogue DF`_\n  | A dwarf-fortress adventure mode-inspired rogue-like Pygame Python3 game.\n- | `learn-spanish-react`_\n  | A WebApp to learn Spanish.\n- | `Learn_vocab`_\n  | Application for German-French vocabulary with simple GUI.\n\n\nCredits\n-------\n\nThis package was created with the help of Verbiste_ and scikit-learn_.\n\nThe logo was designed by Zuur_.\n\n.. _Verbiste: https://perso.b2b2c.ca/~sarrazip/dev/verbiste.html\n.. _scikit-learn: http://scikit-learn.org/stable/index.html\n.. _Zuur: https://github.com/zuuritaly\n.. _`PlanVerb: Domain-Independent Verbalization and Summary of Task Plans`: https://ojs.aaai.org/index.php/AAAI/article/download/21204/version/19491/20953\n.. _`Generative Grading Neural Approximate Parsing for Automated Student Feedback`: https://arxiv.org/abs/1905.09916\n.. _`Fluorescing Questions: Effects of Semantic Perturbations on BERT Performance in SQuAD 1.1`: https://github.com/spencerng/squad-sentiment/blob/87b42a41ba7f4f3f8d4e6c478f746d6cdf9f5515/assets/semantic-perturbations-bert-performance.pdf\n.. _`Extensions and Applications of Deep Probabilistic Inference for Generative Models`: https://drive.google.com/file/d/10IXi-RleFoG9L6G70TEKbAGd-v29R2Zz/view?usp=sharing\n.. _`Gender Bias Visualization`: https://github.com/GesaJo/Gender-Bias-Visualization\n.. _`Text Adaptation To Context`: https://github.com/lzontar/Text_Adaptation_To_Context\n.. _`Facemask Detection`: https://github.com/samuel-karanja/facemask-derection\n.. _`Bad Excuses for Zoom Abuses`: https://github.com/tyxchen/bad-excuses-for-zoom-abuses\n.. _NLP: https://github.com/pskshyam/NLP\n.. _`Virtual Assistant`: https://github.com/JeanExtreme002/Virtual-Assistant\n.. _`Bad Advice`: https://github.com/matthew-cheney/bad-advice\n.. _`Spanish Conjugations Quiz`: https://github.com/williammortimer/Spanish-Conjugations-Quiz\n.. _`Silver Rogue DF`: https://github.com/FranchuFranchu/silver-rogue-df\n.. _`NLP-Suite`: https://github.com/NLP-Suite/NLP-Suite\n.. _`twitter-bot`: https://github.com/arthurcouyere/twitter-bot\n.. _`verb-form-helper`: https://github.com/gittymutt/verb-form-helper\n.. _`NLP Tasks`: https://github.com/ai-systems/poly-nlp\n.. _`verbecc-svc`: https://pypi.org/project/verbecc/\n.. _`nvhtml`: https://pypi.org/project/nvhtml/\n.. _`Machine Translation Service`: https://github.com/pauchai/machine-translation-service\n.. _`Tux`: https://github.com/amirkasraa/Tux\n.. _`learn-spanish-react`: https://github.com/advay168/learn-spanish-react\n.. _`Learn_vocab`: https://github.com/MilaimKas/Learn_vocab\n',
    'author': 'SekouDiaoNlp',
    'author_email': 'diao.sekou.nlp@gmail.com',
    'maintainer': 'SekouDiaoNlp',
    'maintainer_email': 'diao.sekou.nlp@gmail.com',
    'url': 'https://github.com/SekouDiaoNlp/mlconjug3',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8.0,<3.12',
}


setup(**setup_kwargs)
